@@ -1,25 +1,26 @@
 #!/usr/bin/env python
 """
-The fMRIPrep on Docker wrapper
+The *fMRIPrep* on Docker wrapper
 
-
-This is a lightweight Python wrapper to run fMRIPrep.
+This is a lightweight Python wrapper to run *fMRIPrep*.
 Docker must be installed and running. This can be checked
 running ::
 
   docker info
 
-Please report any feedback to our GitHub repository
-(https://github.com/nipreps/fmriprep) and do not
-forget to credit all the authors of software that fMRIPrep
-uses (https://fmriprep.readthedocs.io/en/latest/citing.html).
+Please acknowledge this work using the citation boilerplate that *fMRIPrep* includes
+in the visual report generated for every subject processed.
+For a more detailed description of the citation boilerplate and its relevance,
+please check out the
+`NiPreps documentation <https://www.nipreps.org/intro/transparency/#citation-boilerplates>`__.
+Please report any feedback to our `GitHub repository <https://github.com/nipreps/fmriprep>`__.
 """
 import sys
 import os
 import re
 import subprocess
 
-__version__ = '20.2.5'
+__version__ = '21.0.3'
 __copyright__ = 'Copyright 2020, Center for Reproducible Neuroscience, Stanford University'
 __credits__ = ['Craig Moodie', 'Ross Blair', 'Oscar Esteban', 'Chris Gorgolewski',
                'Shoshana Berleant', 'Christopher J. Markiewicz', 'Russell A. Poldrack']
@@ -29,7 +30,7 @@ __bugreports__ = 'https://github.com/nipreps/fmriprep/issues'
 MISSING = """
 Image '{}' is missing
 Would you like to download? [Y/n] """
-PKG_PATH = '/usr/local/miniconda/lib/python3.7/site-packages'
+PKG_PATH = '/opt/conda/lib/python3.8/site-packages'
 TF_TEMPLATES = (
     'MNI152Lin',
     'MNI152NLin2009cAsym',
@@ -136,6 +137,24 @@ def check_memory(image):
 
 
 def merge_help(wrapper_help, target_help):
+    def _get_posargs(usage):
+        """
+        Extract positional arguments from usage string.
+
+        This function can be used by both native fmriprep (`fmriprep -h`)
+        and the docker wrapper (`fmriprep-docker -h`).
+        """
+        posargs = []
+        for targ in usage.split('\n')[-3:]:
+            line = targ.lstrip()
+            if line.startswith('usage'):
+                continue
+            if line[0].isalnum() or line[0] == "{":
+                posargs.append(line)
+            elif line[0] == '[' and (line[1].isalnum() or line[1] == "{"):
+                posargs.append(line)
+        return " ".join(posargs)
+
     # Matches all flags with up to one nested square bracket
     opt_re = re.compile(r'(\[--?[\w-]+(?:[^\[\]]+(?:\[[^\[\]]+\])?)?\])')
     # Matches flag name only
@@ -150,8 +169,8 @@ def merge_help(wrapper_help, target_help):
     t_usage, t_details = t_help.split('\n\n', 1)
     t_groups = t_details.split('\n\n')
 
-    w_posargs = w_usage.split('\n')[-1].lstrip()
-    t_posargs = t_usage.split('\n')[-1].lstrip()
+    w_posargs = _get_posargs(w_usage)
+    t_posargs = _get_posargs(t_usage)
 
     w_options = opt_re.findall(w_usage)
     w_flags = sum(map(flag_re.findall, w_options), [])
@@ -167,6 +186,7 @@ def merge_help(wrapper_help, target_help):
     expected_overlap = {
         'anat-derivatives',
         'bids-database-dir',
+        'bids-filter-file',
         'fs-license-file',
         'fs-subjects-dir',
         'config-file',
@@ -316,6 +336,12 @@ the spatial normalization.""" % (', '.join('"%s"' % s for s in TF_TEMPLATES),
         '--bids-database-dir', metavar='PATH', type=os.path.abspath,
         help="Path to an existing PyBIDS database folder, for faster indexing "
              "(especially useful for large datasets).")
+    g_wrap.add_argument(
+        '--bids-filter-file', metavar='PATH', type=os.path.abspath,
+        help="a JSON file describing custom BIDS input filters using PyBIDS. "
+        "For further details, please check out "
+        "https://fmriprep.readthedocs.io/en/latest/faq.html#"
+        "how-do-I-select-only-certain-files-to-be-input-to-fMRIPrep")
 
     # Developer patch/shell options
     g_dev = parser.add_argument_group(
@@ -409,7 +435,11 @@ def main():
                'DOCKER_VERSION_8395080871=%s' % docker_version]
 
     if not opts.no_tty:
-        command.append('-it')
+        if opts.help:
+            # TTY can corrupt stdout
+            command.append('-i')
+        else:
+            command.append('-it')
 
     # Patch working repositories into installed package directories
     if opts.patch:
@@ -479,6 +509,10 @@ def main():
         command.extend(['-v', ':'.join((opts.bids_database_dir, '/tmp/bids_db'))])
         unknown_args.extend(['--bids-database-dir', '/tmp/bids_db'])
 
+    if opts.bids_filter_file:
+        command.extend(['-v', ':'.join((opts.bids_filter_file, '/tmp/bids_filter.json'))])
+        unknown_args.extend(['--bids-filter-file', '/tmp/bids_filter.json'])
+
     if opts.output_spaces:
         spaces = []
         for space in opts.output_spaces:
